@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: postgresql-simple
-version: 0.3.3.2
-id: postgresql-simple-0.3.3.2-581833ea2bbfe7ffb1ad6e8e281c2f05
+version: 0.4.0.2
+id: postgresql-simple-0.4.0.2-22e78caeb54d3dd65485bf306aa8cbaf
 
 license: BSD3
 copyright: (c) 2011 MailRank, Inc.
@@ -19,6 +19,7 @@ exposed: True
 exposed-modules: Database.PostgreSQL.Simple
                  Database.PostgreSQL.Simple.Arrays
                  Database.PostgreSQL.Simple.BuiltinTypes
+                 Database.PostgreSQL.Simple.Copy
                  Database.PostgreSQL.Simple.FromField
                  Database.PostgreSQL.Simple.FromRow
                  Database.PostgreSQL.Simple.LargeObjects
@@ -31,6 +32,7 @@ exposed-modules: Database.PostgreSQL.Simple
                  Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
                  Database.PostgreSQL.Simple.Transaction
                  Database.PostgreSQL.Simple.TypeInfo
+                 Database.PostgreSQL.Simple.TypeInfo.Macro
                  Database.PostgreSQL.Simple.TypeInfo.Static
                  Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Errors
                  Database.PostgreSQL.Simple.Internal
@@ -39,30 +41,32 @@ hidden-modules: Database.PostgreSQL.Simple.Compat
                 Database.PostgreSQL.Simple.Time.Implementation
                 Database.PostgreSQL.Simple.TypeInfo.Types
 trusted: False
-import-dirs: /usr/local/lib/ghc/postgresql-simple-0.3.3.2
-library-dirs: /usr/local/lib/ghc/postgresql-simple-0.3.3.2
-hs-libraries: HSpostgresql-simple-0.3.3.2
+import-dirs: /usr/local/lib/ghc/postgresql-simple-0.4.0.2
+library-dirs: /usr/local/lib/ghc/postgresql-simple-0.4.0.2
+hs-libraries: HSpostgresql-simple-0.4.0.2
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: attoparsec-0.10.4.0-d9fd97cfc1a1748b3cde35adf7fd233b
-         base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
+depends: aeson-0.6.2.1-92173c75149e34c3bea9cafc379c1c76
+         attoparsec-0.10.4.0-d9fd97cfc1a1748b3cde35adf7fd233b
+         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
          blaze-builder-0.3.1.1-71a2ae53eb5daf9e6673db8b47b3b6b5
          blaze-textual-0.2.0.8-213811e05d4d4b83315b938a0f25ef12
-         bytestring-0.10.0.2-9e8b487747800a4255d6ff7915c5210f
+         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
          containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
-         postgresql-libpq-0.8.2.2-9725e44a86662267328b5c4ddb0ca6e6
-         template-haskell-2.8.0.0-fea87269e8939065140c93e716ec3dfc
-         text-0.11.3.1-06d227f06409a354e0c77a385328bada
+         postgresql-libpq-0.9.0.1-090b3eef19460778fbfb5ff7cba74ba1
+         template-haskell-2.8.0.0-2f3447bb22ecbbb93fd4d823f6841241
+         text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
          time-1.4.0.1-10dc4804a19dc0000fab79908f1a9f50
          transformers-0.3.0.0-ff2bb6ac67241ebb987351a3db564af0
+         uuid-1.3.3-9517522b49b35db9a6181ea36f0396f3
          vector-0.10.0.1-869166d5d49db46ce6c328ea5f8defbf
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-postgresql-simple-0.3.3.2/html/postgresql-simple.haddock
-haddock-html: /usr/local/share/doc/hs-postgresql-simple-0.3.3.2/html
+haddock-interfaces: /usr/local/share/doc/hs-postgresql-simple-0.4.0.2/html/postgresql-simple.haddock
+haddock-html: /usr/local/share/doc/hs-postgresql-simple-0.4.0.2/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
